==> microsoft.bingads-12.13.5-sources.jar: com/microsoft/bingads/v13/customermanagement/SearchUserInvitationsResponse.java <==

package com.microsoft.bingads.v13.customermanagement;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="UserInvitations" type="{https://bingads.microsoft.com/Customer/v13/Entities}ArrayOfUserInvitation" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "userInvitations"
})
@XmlRootElement(name = "SearchUserInvitationsResponse")
public class SearchUserInvitationsResponse {

    @XmlElement(name = "UserInvitations", nillable = true)
    protected ArrayOfUserInvitation userInvitations;

    /**
     * Gets the value of the userInvitations property.
     * 
     * @return
     *     possible object is
     *     {@link ArrayOfUserInvitation }
     *     
     */
    public ArrayOfUserInvitation getUserInvitations() {
        return userInvitations;
    }

    /**
     * Sets the value of the userInvitations property.
     * 
     * @param value
     *     allowed object is
     *     {@link ArrayOfUserInvitation }
     *     
     */
    public void setUserInvitations(ArrayOfUserInvitation value) {
        this.userInvitations = value;
    }

}

==> microsoft.bingads-13.0.16.1-sources.jar: com/microsoft/bingads/v13/customermanagement/SearchUserInvitationsResponse.java <==

package com.microsoft.bingads.v13.customermanagement;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element name="UserInvitations" type="{https://bingads.microsoft.com/Customer/v13/Entities}ArrayOfUserInvitation" minOccurs="0"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "userInvitations"
})
@XmlRootElement(name = "SearchUserInvitationsResponse")
public class SearchUserInvitationsResponse {

    @XmlElement(name = "UserInvitations", nillable = true)
    protected ArrayOfUserInvitation userInvitations;

    /**
     * Gets the value of the userInvitations property.
     * 
     * @return
     *     possible object is
     *     {@link ArrayOfUserInvitation }
     *     
     */
    public ArrayOfUserInvitation getUserInvitations() {
        return userInvitations;
    }

    /**
     * Sets the value of the userInvitations property.
     * 
     * @param value
     *     allowed object is
     *     {@link ArrayOfUserInvitation }
     *     
     */
    public void setUserInvitations(ArrayOfUserInvitation value) {
        this.userInvitations = value;
    }

}
